@@ -33,7 +33,7 @@ InvalidChecksum: ...
 
 from stdnum.exceptions import *
 from stdnum.iso7064 import mod_11_10
-from stdnum.util import clean
+from stdnum.util import clean, isdigits
 
 
 def compact(number):
@@ -46,7 +46,7 @@ def validate(number):
     """Check if the number is a valid VAT number. This checks the length,
     formatting and check digit."""
     number = compact(number)
-    if not number.isdigit():
+    if not isdigits(number):
         raise InvalidFormat()
     if len(number) != 9:
         raise InvalidLength()
